#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-HJRCq4yRvBYImi3rtyFNqh
key:                  postgrest-10.1.0-HJRCq4yRvBYImi3rtyFNqh
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  1ba4a115ee524d2529617341d6dbd55f
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-HJRCq4yRvBYImi3rtyFNqh
depends:
    HTTP-4000.5.0-1JwLMgbezPG1db1gVJnqXg
    Ranged-sets-0.5.0-Gp5zvUxodsUwORIzO8OWT
    aeson-2.2.2.0-C59vZnSjH3DEmVbOnYEZqj
    auto-update-0.1.6-EaXaTo4pbBvJZBdEC6Dju4 base-4.18.2.1
    base64-bytestring-1.2.1.0-LZzfJtlIG52AkUlWG0qoMe
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-2Yyf9IxnGFQLPP0jk4pg3Q
    cassava-0.5.4.1-2gf6W38zsDc8JksRpwN1Gz
    configurator-pg-0.2.11-INDv6knZYRSGc4wMbcfY56 containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-DQ8gusbvRke83TEO1lNZcm
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-60ZE8JsN8ZP3ajxNPl6i3A
    hasql-dynamic-statements-0.3.1.2-5XQ3En96ByVDmdb7fZZk9j
    hasql-notifications-0.2.0.6-LcXY3wnEhEnIpCmR9JB9JR
    hasql-pool-0.8.0.3-BWIbrhSlI80HPZUPMHv2K5
    hasql-transaction-1.0.1.3-8aC0mgMGsxQ4WKWG1OhsH9
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-57DQrkzau5HINFiGCpRQOB
    insert-ordered-containers-0.2.5.3-Byq2KJUktdn8nDlUFYCpDB
    interpolatedstring-perl6-1.0.2-AjGymoFkdaUDWPC9iD5znu
    jose-0.10.0.1-4GX47d5cwtJLamRh7waYPu
    lens-5.3.5-BDZkiRzgsgQ2kD9evujAJa
    lens-aeson-1.2.3-109DWcpOKe54ubSJm1bpGn mtl-2.3.1
    network-3.1.4.0-FBuTdTHZ29uBPcO3Y238RO
    network-uri-2.6.4.2-Fs1V3yFgC4iGyoDpGJIE7J
    optparse-applicative-0.18.1.0-JRbhqUMlTBkCWkkrIaelno
    parsec-3.1.16.1 protolude-0.3.5-GVTMfEktiy2IzVCjnzfc27
    regex-tdfa-1.3.2.5-9aVe6H9O9607zCidRganW5
    retry-0.9.3.1-AvBGPOoWaDPIoGQMpQu1Xb
    scientific-0.3.8.1-AT3R4FMwAbnHAVDYpRwOmQ
    swagger2-2.9-BCRXC4dsygX90cElkyoEDg text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.21-LjCRrPGX8vKp2UxAfh6M2
    vault-0.3.1.6-XM9k5x10O97eIvn33L375
    vector-0.13.2.0-HJSwbt845rQ2AOZrNm5BDk
    wai-3.2.4-1UZqbeDwj2g6CvYOTQFqve
    wai-cors-0.2.7-34JZ9xMhHvxGoMiOL4Qh9C
    wai-extra-3.1.18-KapEsAdaMBJFSKchm8qsPR
    wai-logger-2.5.0-KdYlLjezEjA6OZip0uwWw5
    warp-3.4.0-HH3FvL2FDvZEcr8ZAiqTxg

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

